@@ -131,10 +131,12 @@ def regex(s):
     return pattern
 
 
-def regex_with_range(s):
+def regex_with_date_range_and_reference_date(s):
+    fmt_example = "Format example: --trend '^costs:food  [2022-01-01:2022-05-31:7] @ 2022-02-01', not {s!r}"
     if m := re.search(
         r"^(?P<pattern>\S+)"
         r"(?:\s+\[(?P<range>(?P<start>[^\]:]*):(?P<end>[^\]:]*))(?::(?P<interval>\d*))?\])?"
+        r"(?:\s+@\s*(?P<reference>\S+)\s*)?"
         r"$",
         s,
     ):
@@ -152,15 +154,18 @@ def regex_with_range(s):
             )
         except Exception as e:
             raise argparse.ArgumentTypeError(
-                f"{d['range']!r} is not a valid time range (error: {e}).\n"
-                f"Format example: --trend '^costs:food  [2022-01-01:2022-05-31:7]', not {s!r}"
+                f"{d['range']!r} is not a valid time range (error: {e}).\n{fmt_example}"
             )
         interval = handle_exception(None, int, d["interval"])
-        return pattern, timerange, interval
+        try:
+            reference = pd.to_datetime(d["reference"] or None)
+        except Exception as e:
+            raise argparse.ArgumentTypeError(
+                f"{d['reference']!r} is not a valid time (error: {e}).\n{fmt_example}"
+            )
+        return pattern, timerange, interval, reference
     else:
-        raise argparse.ArgumentTypeError(
-            f"Format example: '^costs:food  [2022-01-01:2022-05-31:7]', not {s!r}"
-        )
+        raise argparse.ArgumentTypeError(fmt_example)
 
 
 def str_with_index_list(s):
@@ -171,7 +176,7 @@ def str_with_index_list(s):
 
 
 parser = argparse.ArgumentParser(
-    description="""
+    description=f"""
 
 📈  Plot hledger data, browse it interactively and save the graphs
 
@@ -180,12 +185,12 @@ Usage: Replace 'hledger' in your command with 'hledger-plot' or 'hledger plot --
 hledger balance -M Costs
       ⮕  hledger plot -- balance -M Costs (double-dash after 'hledger plot')
       ⮕  hledger-plot    balance -M Costs (invoking hledger-plot directly, no double-dash)
-      ⮕  hledger plot    balance -M Costs (only works without 'hle (version f"{__version__})dger-plot'-specific options)
+      ⮕  hledger plot    balance -M Costs (only works without 'hledger-plot'-specific options)
 
-version {version}, written by Yann Büchau, source code is at https://gitlab.com/nobodyinperson/hledger-utils
+version {__version__}, written by Yann Büchau, source code is at https://gitlab.com/nobodyinperson/hledger-utils
 """.strip(),
     formatter_class=argparse.RawDescriptionHelpFormatter,
-    epilog="""
+    epilog=f"""
 
 ℹ️  Note
 =======
@@ -193,7 +198,7 @@ version {version}, written by Yann Büchau, source code is at https://gitlab.com
 - Currently, only plotting 'hledger balance ...' results is supporting.
   You can get quite close to 'hledger register ...' with 'hledger balance --daily' though.
 - If you get weird errors like 'hledger: Error: Unknown flag XXXX', see above how to invoke hledger-plot
-- Multiple currencies are not really supported, consider converting them via --market, --value or -X or only selecting one currency with cur:€ for example.
+- If you instantly get an error like `/bin/sh: line 1: b: command not found` it probably means you need to do some escaping in your hledger query, especially the pipe character „|” and the asterisk „*”, like `hledger plot -- acct:'a\\|b' --trend '.\\*'`.
 
 🤷 Examples
 ===========
@@ -207,7 +212,7 @@ version {version}, written by Yann Büchau, source code is at https://gitlab.com
 # „How much did and will I pay for that one house?” (if you tagged house transactions with '; house: MyHouse')
 > hledger-plot balance not:acct:^Assets --historical --daily tag:house=MyHouse --pivot=house --forecast --end 2030
 
-Written by Yann Büchau
+version {__version__}, written by Yann Büchau, source code is at https://gitlab.com/nobodyinperson/hledger-utils
 """.strip(),
 )
 parser.add_argument(
@@ -313,8 +318,9 @@ parser_modify_group = parser.add_argument_group(
 )
 parser_modify_group.add_argument(
     "--invert",
+    metavar="REGEX",
     type=regex,
-    help="patterns invert amounts",
+    help="patterns to invert amounts. Default is to invert all.",
     action="append",
     nargs="?",
     default=[],
@@ -388,19 +394,21 @@ parser_modify_group.add_argument(
 )
 parser_modify_group.add_argument(
     "--trend",
-    metavar="REGEX [STARTDATE:ENDDATE:DAYS]",
+    metavar="REGEX [STARTDATE:ENDDATE:DAYS] @ REFERENCEDATE",
     help="Fit a linear trend line to columns matching the REGEX, "
     "optionally only using a specified date range as input. "
-    "Example: '^costs:food [2022-01-01:2022-05-31:7]' to fit a trend "
-    "to the first half of 2022 and show the 7-day slope in the legend. "
+    "Example: '^costs:food [2022-01-01:2022-05-31:7] @ 2022-03-01' to fit a trend "
+    "to the first half of 2022 and show the 7-day slope and the value at start of March in the legend. "
     "Whitespace in the REGEX is not allowed as a space is needed to separate it from the timerange. "
     "You may use a dot (.) instead in the pattern. "
-    "You can leave start and/or end time out or specify 'today', but the colon (:) needs to stay. "
-    "The interval is optional and defaults to 1."
+    "You can leave the date range and the reference date out. If you specify a date range, "
+    "you can leave start and/or end time out or specify 'today', but the colon (:) needs to stay. "
+    "The interval is optional and defaults to 1. "
+    "If you specify a reference date outside the given range, an extrapolation line will be added. "
     "Can be specified multiple times.",
     action="append",
     nargs="?",
-    type=regex_with_range,
+    type=regex_with_date_range_and_reference_date,
     default=[],
 )
 parser_modify_group.add_argument(
@@ -510,7 +518,14 @@ def cli(cli_args=sys.argv[1:]):
             "setting mapping to {args.mean}"
         )
     if args.trend == [None]:
-        args.trend = [(re.compile(r".*"), slice(None, None, None), None)]
+        args.trend = [
+            (
+                re.compile(r".*"),
+                slice(None, None, None),
+                None,
+                None,
+            )
+        ]
         logger.debug(
             f"Assuming you want to add a --trend for all columns, "
             "setting selector to {args.trend}"
@@ -667,7 +682,7 @@ def cli(cli_args=sys.argv[1:]):
         )
 
     # Try to auto-format commodities right
-    # TODO: Can be prevent this loop by using `hledger stats` for example to
+    # TODO: Can we prevent this loop by using `hledger stats` for example to
     # know the commodities in advance? Although hledger stats also parses
     # everything so might not be much of a benefit...
     if missing_values := data["value"].isna().sum():
@@ -704,15 +719,22 @@ def cli(cli_args=sys.argv[1:]):
 
     groupby = ["account", "commodity"]
     logger.info(f"Grouping accounts and commodities by {groupby}")
-    data = pd.concat(
-        [
+    account_commodities = {}
+    data_to_concat = []
+    for n, g in data.groupby(groupby):
+        data_to_concat.append(
             g["value"].rename(
-                args.account_format.format(**dict(zip(groupby, n)))
+                newname := args.account_format.format(
+                    **(m := dict(zip(groupby, n)))
+                )
             )
-            for n, g in data.groupby(groupby)
-        ],
+        )
+        account_commodities[newname] = m.get("commodity", "")
+    data = pd.concat(
+        data_to_concat,
         axis="columns",
     )
+    logger.debug(f"{account_commodities = }")
     logger.debug(f"data = \n{data}")
 
     if args.terminal:
@@ -842,7 +864,7 @@ pip install windows-curses
     def trend_handler(trenddefs, data=data):
         for trenddef in trenddefs:
             logger.debug(f"{trenddef = }")
-            pattern, timerange, interval = trenddef
+            pattern, timerange, interval, reference = trenddef
             if interval is None:
                 interval = next(
                     (
@@ -861,20 +883,66 @@ pip install windows-curses
             if cols_to_fit := list(filter(pattern.search, data)):
                 for col in cols_to_fit:
                     series = data.loc[timerange, col]
-                    days = series.index.map(pd.Timestamp.timestamp) / (
-                        24 * 60 * 60
-                    )
-                    fit = scipy.stats.linregress(days, series)
+                    logger.debug(f"series = \n{series}")
+                    days_since_reference = (
+                        series.index.map(pd.Timestamp.timestamp)
+                        - (reference.timestamp() if reference else 0)
+                    ) / (24 * 60 * 60)
+                    fit = scipy.stats.linregress(days_since_reference, series)
+
+                    def oma(x):
+                        # orders of magnitude in amounts
+                        return (
+                            int(np.ceil(np.log10(abs(x)))) if abs(x) > 0 else 0
+                        )
+
+                    def autofmt(x, showsign=False):
+                        digits = np.clip(2 - oma(x), 0, None)
+                        fmt = f"{{:{'+' if showsign else ''}.{digits}f}} {account_commodities.get(col,'')}"
+                        return fmt.format(x)
+
                     logger.debug(f"{fit = }")
-                    data.loc[
-                        timerange,
-                        f"{col} trend ({fit.slope * interval:+f}"
-                        " / "
-                        f"{str(interval)+' ' if interval != 1 else ''}"
-                        f"day{'s' if interval!=1 else ''})",
-                    ] = (
-                        days * fit.slope + fit.intercept
+                    trend_colname_base = f"{col} trend"
+                    trend_colname_slope = f"({autofmt(fit.slope * interval,showsign=True)}/{str(interval) if interval != 1 else ''}day{'s' if interval!=1 else ''})"
+                    trend_colname_mean = f"⌀ = {autofmt(series.mean())}"
+                    predicted = (
+                        days_since_reference * fit.slope + fit.intercept
                     )
+                    trend_colname = f"{trend_colname_base} {trend_colname_slope} {trend_colname_mean}"
+                    if reference:
+                        trend_colname_reference = f"{autofmt(fit.intercept)} @ {reference.strftime('%Y-%m-%d')}"
+                        t = series.index
+                        if not (t.min() <= reference <= t.max()):
+                            i = 0 if reference < t.min() else (t.size - 1)
+                            extrapolation = pd.Series(
+                                [fit.intercept, predicted[i]],
+                                name=f"{trend_colname_base} extrapolation {trend_colname_reference}",
+                                index=[reference, t[i]],
+                            ).sort_index()
+                            logger.debug(f"extrapolation = \n{extrapolation}")
+                            # add extrapolation to data
+                            data = pd.concat(
+                                [data, extrapolation.to_frame()],
+                                axis="columns",
+                            ).sort_index()
+                            logger.debug(
+                                f"after joining extrapolation: data = \n{data}"
+                            )
+                        else:
+                            trend_colname = (
+                                f"{trend_colname} {trend_colname_reference}"
+                            )
+                    data = pd.concat(
+                        [
+                            data,
+                            pd.Series(
+                                predicted,
+                                name=trend_colname,
+                                index=series.index,
+                            ).to_frame(),
+                        ],
+                        axis="columns",
+                    ).sort_index()
             else:
                 logger.warning(
                     f"--trend pattern {pattern.pattern!r} didn't match any columns."
@@ -967,8 +1035,10 @@ pip install windows-curses
 
             used_styles = list()
             for column in data:
-                series = data[column]
-                plot_kwargs = dict(drawstyle=args.drawstyle, label=column)
+                series = data[column].dropna()
+                plot_kwargs = dict(
+                    drawstyle=args.drawstyle, label=column.replace(r"$", r"\$")
+                )
                 if args.style:
                     # apply styles
                     for pattern, kwargs in args.style:
